==> mx-packageinstaller-pkglist_19.05.03.tar.xz: mx-packageinstaller-pkglist/Thai_Firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Thai_Firefox
</name>

<description>
   <am>Thai localisation of Firefox</am>
   <ar>Thai localisation of Firefox</ar>
   <bg>Thai localisation of Firefox</bg>
   <ca>Localització de Firefox en Tailandès</ca>
   <cs>Thai localisation of Firefox</cs>
   <da>Thai oversættelse af Firefox</da>
   <de>Thailändische Lokalisierung von Firefox</de>
   <el>Ταϊλάνδης εντοπισμός του Firefox</el>
   <en>Thai localisation of Firefox</en>
   <es>Thai localisation of Firefox</es>
   <et>Thai localisation of Firefox</et>
   <eu>Thai localisation of Firefox</eu>
   <fa>Thai localisation of Firefox</fa>
   <fi>Thai localisation of Firefox</fi>
   <fr>Localisation thai pour Firefox</fr>
   <he_IL>Thai localisation of Firefox</he_IL>
   <hi>Thai localisation of Firefox</hi>
   <hr>Thai localisation of Firefox</hr>
   <hu>Thai localisation of Firefox</hu>
   <id>Thai localisation of Firefox</id>
   <is>Thai localisation of Firefox</is>
   <it>Localizzazione tailandese di Firefox</it>
   <ja_JP>Thai localisation of Firefox</ja_JP>
   <ja>Thai localisation of Firefox</ja>
   <kk>Thai localisation of Firefox</kk>
   <ko>Thai localisation of Firefox</ko>
   <lt>Thai localisation of Firefox</lt>
   <mk>Thai localisation of Firefox</mk>
   <nb>Thai localisation of Firefox</nb>
   <nl>Thaise lokalisatie van Firefox</nl>
   <pl>Tajska lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Tailandês Localização para Firefox</pt_BR>
   <pt>Tailandês Localização para Firefox</pt>
   <ro>Thai localisation of Firefox</ro>
   <ru>Thai localisation of Firefox</ru>
   <sk>Thai localisation of Firefox</sk>
   <sl>Thai localisation of Firefox</sl>
   <sq>Thai localisation of Firefox</sq>
   <sr>Thai localisation of Firefox</sr>
   <sv>Thailändsk lokalisering av Firefox</sv>
   <tr>Thai localisation of Firefox</tr>
   <uk>Thai localisation of Firefox</uk>
   <zh_CN>Thai localisation of Firefox</zh_CN>
   <zh_TW>Thai localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-th
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-th
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.02.tar.xz: mx-packageinstaller-pkglist/Thai_Firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Thai_Firefox
</name>

<description>
   <am>Thai localisation of Firefox</am>
   <ar>Thai localisation of Firefox</ar>
   <bg>Thai localisation of Firefox</bg>
   <ca>Localització de Firefox en Tailandès</ca>
   <cs>Thai localisation of Firefox</cs>
   <da>Thai oversættelse af Firefox</da>
   <de>Thailändische Lokalisierung von Firefox</de>
   <el>Ταϊλάνδης εντοπισμός του Firefox</el>
   <en>Thai localisation of Firefox</en>
   <es>Localización Tailandesa de Firefox</es>
   <et>Thai localisation of Firefox</et>
   <eu>Thai localisation of Firefox</eu>
   <fa>Thai localisation of Firefox</fa>
   <fi>Thai localisation of Firefox</fi>
   <fr>Localisation thai pour Firefox</fr>
   <he_IL>Thai localisation of Firefox</he_IL>
   <hi>Thai localisation of Firefox</hi>
   <hr>Thai localisation of Firefox</hr>
   <hu>Thai localisation of Firefox</hu>
   <id>Thai localisation of Firefox</id>
   <is>Thai localisation of Firefox</is>
   <it>Localizzazione tailandese di Firefox</it>
   <ja_JP>Thai localisation of Firefox</ja_JP>
   <ja>Thai localisation of Firefox</ja>
   <kk>Thai localisation of Firefox</kk>
   <ko>Thai localisation of Firefox</ko>
   <lt>Thai localisation of Firefox</lt>
   <mk>Thai localisation of Firefox</mk>
   <nb>Thai localisation of Firefox</nb>
   <nl>Thaise lokalisatie van Firefox</nl>
   <pl>Tajska lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Tailandês Localização para Firefox</pt_BR>
   <pt>Tailandês Localização para Firefox</pt>
   <ro>Thai localisation of Firefox</ro>
   <ru>Тайская локализация Firefox</ru>
   <sk>Thai localisation of Firefox</sk>
   <sl>Thai localisation of Firefox</sl>
   <sq>Thai localisation of Firefox</sq>
   <sr>Thai localisation of Firefox</sr>
   <sv>Thailändsk lokalisering av Firefox</sv>
   <tr>Thai localisation of Firefox</tr>
   <uk>Thai localisation of Firefox</uk>
   <zh_CN>Thai localisation of Firefox</zh_CN>
   <zh_TW>Thai localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-th
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-th
</uninstall_package_names>
</app>
